Class: RailsSemanticLogger::ActionController::LogSubscriber

Inherits:
ActiveSupport::LogSubscriber show all
Defined in:
lib/rails_semantic_logger/action_controller/log_subscriber.rb

Constant Summary collapse

INTERNAL_PARAMS =
%w[controller action format _method only_path].freeze

Class Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from ActiveSupport::LogSubscriber

#silenced?

Class Attribute Details

.action_message_formatObject

Returns the value of attribute action_message_format.



7
8
9
# File 'lib/rails_semantic_logger/action_controller/log_subscriber.rb', line 7

def action_message_format
  @action_message_format
end

Instance Method Details

#halted_callback(event) ⇒ Object



73
74
75
# File 'lib/rails_semantic_logger/action_controller/log_subscriber.rb', line 73

def halted_callback(event)
  controller_logger(event).info { "Filter chain halted as #{event.payload[:filter].inspect} rendered or redirected" }
end

#process_action(event) ⇒ Object



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/rails_semantic_logger/action_controller/log_subscriber.rb', line 15

def process_action(event)
  controller_logger(event).info do
    payload = event.payload.dup

    # Unused, but needed for Devise 401 status code monkey patch to still work.
    ::ActionController::Base.log_process_action(payload)

    params = payload[:params]

    if params.is_a?(Hash) || params.is_a?(::ActionController::Parameters)
      # According to PR https://github.com/reidmorrison/rails_semantic_logger/pull/37/files
      # params is not always a Hash.
      payload[:params] = params.to_unsafe_h unless params.is_a?(Hash)
      payload[:params] = params.except(*INTERNAL_PARAMS)

      if payload[:params].empty?
        payload.delete(:params)
      elsif params["file"]
        # When logging to JSON the entire tempfile is logged, so convert it to a string.
        payload[:params]["file"] = params["file"].inspect
      end
    end

    format           = payload[:format]
    payload[:format] = format.to_s.upcase if format.is_a?(Symbol)

    payload[:path]   = extract_path(payload[:path]) if payload.key?(:path)

    exception = payload.delete(:exception)
    if payload[:status].nil? && exception.present?
      exception_class_name = exception.first
      payload[:status]     = ActionDispatch::ExceptionWrapper.status_code_for_exception(exception_class_name)
    end

    # Rounds off the runtimes. For example, :view_runtime, :mongo_runtime, etc.
    payload.keys.each do |key|
      payload[key] = payload[key].to_f.round(2) if key.to_s =~ /(.*)_runtime/
    end

    # Rails 6+ includes allocation count
    payload[:allocations] = event.allocations if event.respond_to?(:allocations)

    payload[:status_message] = ::Rack::Utils::HTTP_STATUS_CODES[payload[:status]] if payload[:status].present?

    # Causes excessive log output with Rails 5 RC1
    payload.delete(:headers)
    # Causes recursion in Rails 6.1.rc1
    payload.delete(:request)
    payload.delete(:response)

    {
      message:  action_message("Completed", event.payload),
      duration: event.duration,
      payload:  payload
    }
  end
end

#redirect_to(event) ⇒ Object



81
82
83
# File 'lib/rails_semantic_logger/action_controller/log_subscriber.rb', line 81

def redirect_to(event)
  controller_logger(event).info(message: "Redirected to", payload: {location: event.payload[:location]})
end

#send_data(event) ⇒ Object



85
86
87
88
89
# File 'lib/rails_semantic_logger/action_controller/log_subscriber.rb', line 85

def send_data(event)
  controller_logger(event).info(message:  "Sent data",
                                payload:  {file_name: event.payload[:filename]},
                                duration: event.duration)
end

#send_file(event) ⇒ Object



77
78
79
# File 'lib/rails_semantic_logger/action_controller/log_subscriber.rb', line 77

def send_file(event)
  controller_logger(event).info(message: "Sent file", payload: {path: event.payload[:path]}, duration: event.duration)
end

#start_processing(event) ⇒ Object

Log as debug to hide Processing messages in production



11
12
13
# File 'lib/rails_semantic_logger/action_controller/log_subscriber.rb', line 11

def start_processing(event)
  controller_logger(event).debug { action_message("Processing", event.payload) }
end

#unpermitted_parameters(event) ⇒ Object



91
92
93
94
95
96
# File 'lib/rails_semantic_logger/action_controller/log_subscriber.rb', line 91

def unpermitted_parameters(event)
  controller_logger(event).debug do
    unpermitted_keys = event.payload[:keys]
    "Unpermitted parameter#{'s' if unpermitted_keys.size > 1}: #{unpermitted_keys.join(', ')}"
  end
end